# streamtools
Tools for modeling and analyzing stellar streams

[![Documentation Status](https://readthedocs.org/projects/streamtools/badge/?version=latest)](https://streamtools.readthedocs.io/en/latest/?badge=latest)


## Development

* Bump version using:

  * ``bumpversion release`` when releasing (removes ``.devX`` part of
     the version)

  * ``bumpversion minor`` (go from ``X.Y`` to ``X.Y+1.dev0``)

  * ``bumpversion major`` (go from ``X.Y`` to ``X+1.0.dev0``).

